aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java
diff options
context:
space:
mode:
authorGravatar Googler <noreply@google.com>2015-04-22 21:56:57 +0000
committerGravatar Laszlo Csomor <laszlocsomor@google.com>2015-04-23 09:19:32 +0000
commite31b97436487c6f99280f2ff776661b9a6287791 (patch)
tree8b7d3e13cbfd7845ec16673b5c9e13decabb7db0 /src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java
parentbfb76a97dd54f49c0df2be5117301fdeb2c75654 (diff)
Enables BlazeModule to return multiple ActionContextProviders and ActionContextConsumers.
-- MOS_MIGRATED_REVID=91827715
Diffstat (limited to 'src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java')
-rw-r--r--src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java b/src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java
index 1385647615..884b0ec96e 100644
--- a/src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java
+++ b/src/main/java/com/google/devtools/build/lib/runtime/BlazeModule.java
@@ -298,24 +298,24 @@ public abstract class BlazeModule {
}
/**
* Returns the action context provider the module contributes to Blaze, if any.
*
* <p>This method will be called at the beginning of the execution phase, e.g. of the
* "blaze build" command.
*/
- public ActionContextProvider getActionContextProvider() {
- return null;
+ public Iterable<ActionContextProvider> getActionContextProviders() {
+ return ImmutableList.of();
}
/**
* Returns the action context consumer that pulls in action contexts required by this module,
* if any.
*
* <p>This method will be called at the beginning of the execution phase, e.g. of the
* "blaze build" command.
*/
- public ActionContextConsumer getActionContextConsumer() {
- return null;
+ public Iterable<ActionContextConsumer> getActionContextConsumers() {
+ return ImmutableList.of();
}
/**
@@ -298,24 +298,24 @@ public abstract class BlazeModule {
}
/**
- * Returns the action context provider the module contributes to Blaze, if any.
+ * Returns the action context providers the module contributes to Blaze, if any.
*
* <p>This method will be called at the beginning of the execution phase, e.g. of the
@@ -298,24 +298,24 @@ public abstract class BlazeModule {
}
/**
- * Returns the action context consumer that pulls in action contexts required by this module,
+ * Returns the action context consumers that pulls in action contexts required by this module,
* if any.
*